@@ -1,16 +1,18 @@
 //! Builder for the number format.
 
-use crate::format_flags as flags;
 use core::{mem, num};
+
 use static_assertions::const_assert;
 
+use crate::format_flags as flags;
+
 /// Type with the exact same size as a `u8`.
 pub type OptionU8 = Option<num::NonZeroU8>;
 
 // Ensure the sizes are identical.
 const_assert!(mem::size_of::<OptionU8>() == mem::size_of::<u8>());
 
-/// Add single flag to SyntaxFormat.
+/// Add single flag to `SyntaxFormat`.
 macro_rules! add_flag {
     ($format:ident, $bool:expr, $flag:ident) => {
         if $bool {
@@ -19,7 +21,7 @@ macro_rules! add_flag {
     };
 }
 
-/// Add multiple flags to SyntaxFormat.
+/// Add multiple flags to `SyntaxFormat`.
 macro_rules! add_flags {
     ($format:ident ; $($bool:expr, $flag:ident ;)*) => {{
         $(add_flag!($format, $bool, $flag);)*
@@ -53,38 +55,70 @@ const fn unwrap_or_zero(option: OptionU8) -> u8 {
 /// * `mantissa_radix`                          - Radix for mantissa digits.
 /// * `exponent_base`                           - Base for the exponent.
 /// * `exponent_radix`                          - Radix for the exponent digits.
-/// * `base_prefix`                             - Optional character for the base prefix.
-/// * `base_suffix`                             - Optional character for the base suffix.
-/// * `required_integer_digits`                 - If digits are required before the decimal point.
-/// * `required_fraction_digits`                - If digits are required after the decimal point.
-/// * `required_exponent_digits`                - If digits are required after the exponent character.
-/// * `required_mantissa_digits`                - If at least 1 significant digit is required.
-/// * `no_positive_mantissa_sign`               - If positive sign before the mantissa is not allowed.
-/// * `required_mantissa_sign`                  - If positive sign before the mantissa is required.
-/// * `no_exponent_notation`                    - If exponent notation is not allowed.
-/// * `no_positive_exponent_sign`               - If positive sign before the exponent is not allowed.
-/// * `required_exponent_sign`                  - If sign before the exponent is required.
-/// * `no_exponent_without_fraction`            - If exponent without fraction is not allowed.
-/// * `no_special`                              - If special (non-finite) values are not allowed.
-/// * `case_sensitive_special`                  - If special (non-finite) values are case-sensitive.
-/// * `no_integer_leading_zeros`                - If leading zeros before an integer are not allowed.
-/// * `no_float_leading_zeros`                  - If leading zeros before a float are not allowed.
-/// * `required_exponent_notation`              - If exponent notation is required.
-/// * `case_sensitive_exponent`                 - If exponent characters are case-sensitive.
-/// * `case_sensitive_base_prefix`              - If base prefixes are case-sensitive.
-/// * `case_sensitive_base_suffix`              - If base suffixes are case-sensitive.
-/// * `integer_internal_digit_separator`        - If digit separators are allowed between integer digits.
-/// * `fraction_internal_digit_separator`       - If digit separators are allowed between fraction digits.
-/// * `exponent_internal_digit_separator`       - If digit separators are allowed between exponent digits.
-/// * `integer_leading_digit_separator`         - If a digit separator is allowed before any integer digits.
-/// * `fraction_leading_digit_separator`        - If a digit separator is allowed before any fraction digits.
-/// * `exponent_leading_digit_separator`        - If a digit separator is allowed before any exponent digits.
-/// * `integer_trailing_digit_separator`        - If a digit separator is allowed after any integer digits.
-/// * `fraction_trailing_digit_separator`       - If a digit separator is allowed after any fraction digits.
-/// * `exponent_trailing_digit_separator`       - If a digit separator is allowed after any exponent digits.
-/// * `integer_consecutive_digit_separator`     - If multiple consecutive integer digit separators are allowed.
-/// * `fraction_consecutive_digit_separator`    - If multiple consecutive fraction digit separators are allowed.
-/// * `special_digit_separator`                 - If any digit separators are allowed in special (non-finite) values.
+/// * `base_prefix`                             - Optional character for the
+///   base prefix.
+/// * `base_suffix`                             - Optional character for the
+///   base suffix.
+/// * `required_integer_digits`                 - If digits are required before
+///   the decimal point.
+/// * `required_fraction_digits`                - If digits are required after
+///   the decimal point.
+/// * `required_exponent_digits`                - If digits are required after
+///   the exponent character.
+/// * `required_mantissa_digits`                - If at least 1 significant
+///   digit is required.
+/// * `no_positive_mantissa_sign`               - If positive sign before the
+///   mantissa is not allowed.
+/// * `required_mantissa_sign`                  - If positive sign before the
+///   mantissa is required.
+/// * `no_exponent_notation`                    - If exponent notation is not
+///   allowed.
+/// * `no_positive_exponent_sign`               - If positive sign before the
+///   exponent is not allowed.
+/// * `required_exponent_sign`                  - If sign before the exponent is
+///   required.
+/// * `no_exponent_without_fraction`            - If exponent without fraction
+///   is not allowed.
+/// * `no_special`                              - If special (non-finite) values
+///   are not allowed.
+/// * `case_sensitive_special`                  - If special (non-finite) values
+///   are case-sensitive.
+/// * `no_integer_leading_zeros`                - If leading zeros before an
+///   integer are not allowed.
+/// * `no_float_leading_zeros`                  - If leading zeros before a
+///   float are not allowed.
+/// * `required_exponent_notation`              - If exponent notation is
+///   required.
+/// * `case_sensitive_exponent`                 - If exponent characters are
+///   case-sensitive.
+/// * `case_sensitive_base_prefix`              - If base prefixes are
+///   case-sensitive.
+/// * `case_sensitive_base_suffix`              - If base suffixes are
+///   case-sensitive.
+/// * `integer_internal_digit_separator`        - If digit separators are
+///   allowed between integer digits.
+/// * `fraction_internal_digit_separator`       - If digit separators are
+///   allowed between fraction digits.
+/// * `exponent_internal_digit_separator`       - If digit separators are
+///   allowed between exponent digits.
+/// * `integer_leading_digit_separator`         - If a digit separator is
+///   allowed before any integer digits.
+/// * `fraction_leading_digit_separator`        - If a digit separator is
+///   allowed before any fraction digits.
+/// * `exponent_leading_digit_separator`        - If a digit separator is
+///   allowed before any exponent digits.
+/// * `integer_trailing_digit_separator`        - If a digit separator is
+///   allowed after any integer digits.
+/// * `fraction_trailing_digit_separator`       - If a digit separator is
+///   allowed after any fraction digits.
+/// * `exponent_trailing_digit_separator`       - If a digit separator is
+///   allowed after any exponent digits.
+/// * `integer_consecutive_digit_separator`     - If multiple consecutive
+///   integer digit separators are allowed.
+/// * `fraction_consecutive_digit_separator`    - If multiple consecutive
+///   fraction digit separators are allowed.
+/// * `special_digit_separator`                 - If any digit separators are
+///   allowed in special (non-finite) values.
 ///
 /// # Write Integer Fields
 ///
@@ -202,7 +236,7 @@ pub struct NumberFormatBuilder {
 impl NumberFormatBuilder {
     // CONSTRUCTORS
 
-    /// Create new NumberFormatBuilder with default arguments.
+    /// Create new `NumberFormatBuilder` with default arguments.
     #[inline(always)]
     pub const fn new() -> Self {
         Self {
@@ -430,54 +464,84 @@ impl NumberFormatBuilder {
     }
 
     /// Get if digit separators are allowed between integer digits.
+    ///
+    /// This will not consider an input of only the digit separator
+    /// to be a valid separator: the digit separator must be surrounded by
+    /// digits.
     #[inline(always)]
     pub const fn get_integer_internal_digit_separator(&self) -> bool {
         self.integer_internal_digit_separator
     }
 
     /// Get if digit separators are allowed between fraction digits.
+    ///
+    /// This will not consider an input of only the digit separator
+    /// to be a valid separator: the digit separator must be surrounded by
+    /// digits.
     #[inline(always)]
     pub const fn get_fraction_internal_digit_separator(&self) -> bool {
         self.fraction_internal_digit_separator
     }
 
     /// Get if digit separators are allowed between exponent digits.
+    ///
+    /// This will not consider an input of only the digit separator
+    /// to be a valid separator: the digit separator must be surrounded by
+    /// digits.
     #[inline(always)]
     pub const fn get_exponent_internal_digit_separator(&self) -> bool {
         self.exponent_internal_digit_separator
     }
 
     /// Get if a digit separator is allowed before any integer digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     pub const fn get_integer_leading_digit_separator(&self) -> bool {
         self.integer_leading_digit_separator
     }
 
     /// Get if a digit separator is allowed before any fraction digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     pub const fn get_fraction_leading_digit_separator(&self) -> bool {
         self.fraction_leading_digit_separator
     }
 
     /// Get if a digit separator is allowed before any exponent digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     pub const fn get_exponent_leading_digit_separator(&self) -> bool {
         self.exponent_leading_digit_separator
     }
 
     /// Get if a digit separator is allowed after any integer digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     pub const fn get_integer_trailing_digit_separator(&self) -> bool {
         self.integer_trailing_digit_separator
     }
 
     /// Get if a digit separator is allowed after any fraction digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     pub const fn get_fraction_trailing_digit_separator(&self) -> bool {
         self.fraction_trailing_digit_separator
     }
 
     /// Get if a digit separator is allowed after any exponent digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     pub const fn get_exponent_trailing_digit_separator(&self) -> bool {
         self.exponent_trailing_digit_separator
@@ -720,6 +784,10 @@ impl NumberFormatBuilder {
     }
 
     /// Set if digit separators are allowed between integer digits.
+    ///
+    /// This will not consider an input of only the digit separator
+    /// to be a valid separator: the digit separator must be surrounded by
+    /// digits.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn integer_internal_digit_separator(mut self, flag: bool) -> Self {
@@ -728,6 +796,10 @@ impl NumberFormatBuilder {
     }
 
     /// Set if digit separators are allowed between fraction digits.
+    ///
+    /// This will not consider an input of only the digit separator
+    /// to be a valid separator: the digit separator must be surrounded by
+    /// digits.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn fraction_internal_digit_separator(mut self, flag: bool) -> Self {
@@ -736,6 +808,10 @@ impl NumberFormatBuilder {
     }
 
     /// Set if digit separators are allowed between exponent digits.
+    ///
+    /// This will not consider an input of only the digit separator
+    /// to be a valid separator: the digit separator must be surrounded by
+    /// digits.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn exponent_internal_digit_separator(mut self, flag: bool) -> Self {
@@ -744,6 +820,10 @@ impl NumberFormatBuilder {
     }
 
     /// Set all internal digit separator flags.
+    ///
+    /// This will not consider an input of only the digit separator
+    /// to be a valid separator: the digit separator must be surrounded by
+    /// digits.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn internal_digit_separator(mut self, flag: bool) -> Self {
@@ -754,6 +834,9 @@ impl NumberFormatBuilder {
     }
 
     /// Set if a digit separator is allowed before any integer digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn integer_leading_digit_separator(mut self, flag: bool) -> Self {
@@ -762,6 +845,9 @@ impl NumberFormatBuilder {
     }
 
     /// Set if a digit separator is allowed before any fraction digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn fraction_leading_digit_separator(mut self, flag: bool) -> Self {
@@ -770,6 +856,9 @@ impl NumberFormatBuilder {
     }
 
     /// Set if a digit separator is allowed before any exponent digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn exponent_leading_digit_separator(mut self, flag: bool) -> Self {
@@ -778,6 +867,9 @@ impl NumberFormatBuilder {
     }
 
     /// Set all leading digit separator flags.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn leading_digit_separator(mut self, flag: bool) -> Self {
@@ -788,6 +880,9 @@ impl NumberFormatBuilder {
     }
 
     /// Set if a digit separator is allowed after any integer digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn integer_trailing_digit_separator(mut self, flag: bool) -> Self {
@@ -796,6 +891,9 @@ impl NumberFormatBuilder {
     }
 
     /// Set if a digit separator is allowed after any fraction digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn fraction_trailing_digit_separator(mut self, flag: bool) -> Self {
@@ -804,6 +902,9 @@ impl NumberFormatBuilder {
     }
 
     /// Set if a digit separator is allowed after any exponent digits.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn exponent_trailing_digit_separator(mut self, flag: bool) -> Self {
@@ -812,6 +913,9 @@ impl NumberFormatBuilder {
     }
 
     /// Set all trailing digit separator flags.
+    ///
+    /// This will consider an input of only the digit separator
+    /// to be a identical to empty input.
     #[inline(always)]
     #[cfg(feature = "format")]
     pub const fn trailing_digit_separator(mut self, flag: bool) -> Self {
@@ -915,7 +1019,7 @@ impl NumberFormatBuilder {
     /// (and therefore unwrapping Errors/Options) in const fns. It is
     /// therefore up to you to ensure the format is valid, called via the
     /// `is_valid` function on `NumberFormat`.
-    #[inline]
+    #[inline(always)]
     pub const fn build(&self) -> u128 {
         let mut format: u128 = 0;
         add_flags!(
@@ -966,7 +1070,7 @@ impl NumberFormatBuilder {
     }
 
     /// Re-create builder from format.
-    #[inline]
+    #[inline(always)]
     pub const fn rebuild(format: u128) -> Self {
         NumberFormatBuilder {
             digit_separator: num::NonZeroU8::new(flags::digit_separator(format)),
