@@ -108,7 +108,7 @@
 //! In order to limit the format specification and avoid parsing
 //! non-numerical data, all number formats require some significant
 //! digits. Examples of always invalid numbers include:
-//! - ``
+//! - ` `
 //! - `.`
 //! - `e`
 //! - `e7`
@@ -158,50 +158,50 @@
 //! Currently Supported Programming and Data Languages:
 //! ---------------------------------------------------
 //!
-//! 1. Rust
-//! 2. Python
-//! 3. C++ (98, 03, 11, 14, 17)
-//! 4. C (89, 90, 99, 11, 18)
-//! 5. Ruby
-//! 6. Swift
-//! 7. Go
-//! 8. Haskell
-//! 9. Javascript
-//! 10. Perl
-//! 11. PHP
-//! 12. Java
-//! 13. R
-//! 14. Kotlin
-//! 15. Julia
-//! 16. C# (ISO-1, ISO-2, 3, 4, 5, 6, 7)
-//! 17. Kawa
-//! 18. Gambit-C
-//! 19. Guile
-//! 20. Clojure
-//! 21. Erlang
-//! 22. Elm
-//! 23. Scala
-//! 24. Elixir
-//! 25. FORTRAN
-//! 26. D
-//! 27. Coffeescript
-//! 28. Cobol
-//! 29. F#
-//! 30. Visual Basic
-//! 31. OCaml
-//! 32. Objective-C
-//! 33. ReasonML
-//! 34. Octave
-//! 35. Matlab
-//! 36. Zig
-//! 37. SageMath
-//! 38. JSON
-//! 39. TOML
-//! 40. XML
-//! 41. SQLite
-//! 42. PostgreSQL
-//! 43. MySQL
-//! 44. MongoDB
+//! 1. `Rust`
+//! 2. `Python`
+//! 3. `C++` (98, 03, 11, 14, 17)
+//! 4. `C` (89, 90, 99, 11, 18)
+//! 5. `Ruby`
+//! 6. `Swift`
+//! 7. `Go`
+//! 8. `Haskell`
+//! 9. `Javascript`
+//! 10. `Perl`
+//! 11. `PHP`
+//! 12. `Java`
+//! 13. `R`
+//! 14. `Kotlin`
+//! 15. `Julia`
+//! 16. `C#` (ISO-1, ISO-2, 3, 4, 5, 6, 7)
+//! 17. `Kawa`
+//! 18. `Gambit-C`
+//! 19. `Guile`
+//! 20. `Clojure`
+//! 21. `Erlang`
+//! 22. `Elm`
+//! 23. `Scala`
+//! 24. `Elixir`
+//! 25. `FORTRAN`
+//! 26. `D`
+//! 27. `Coffeescript`
+//! 28. `Cobol`
+//! 29. `F#`
+//! 30. `Visual Basic`
+//! 31. `OCaml`
+//! 32. `Objective-C`
+//! 33. `ReasonML`
+//! 34. `Octave`
+//! 35. `Matlab`
+//! 36. `Zig`
+//! 37. `SageMath`
+//! 38. `JSON`
+//! 39. `TOML`
+//! 40. `XML`
+//! 41. `SQLite`
+//! 42. `PostgreSQL`
+//! 43. `MySQL`
+//! 44. `MongoDB`
 
 #![cfg_attr(rustfmt, rustfmt::skip)]
 
@@ -466,10 +466,10 @@ pub const MANTISSA_RADIX_SHIFT: i32 = 104;
 /// Mask to extract the mantissa radix: the radix for the significant digits.
 pub const MANTISSA_RADIX: u128 = 0xFF << MANTISSA_RADIX_SHIFT;
 
-/// Alias for MANTISSA_RADIX_SHIFT.
+/// Alias for `MANTISSA_RADIX_SHIFT`.
 pub const RADIX_SHIFT: i32 = MANTISSA_RADIX_SHIFT;
 
-/// Alias for MANTISSA_RADIX.
+/// Alias for `MANTISSA_RADIX`.
 pub const RADIX: u128 = MANTISSA_RADIX;
 
 /// Shift to convert to and from an exponent base as a `u32`.
@@ -600,32 +600,32 @@ pub const EXPONENT_DIGIT_SEPARATOR_FLAG_MASK: u128 =
 // ----------
 
 /// Extract the digit separator from the format packed struct.
-#[inline]
+#[inline(always)]
 pub const fn digit_separator(format: u128) -> u8 {
     ((format & DIGIT_SEPARATOR) >> DIGIT_SEPARATOR_SHIFT) as u8
 }
 
 /// Extract the base prefix character from the format packed struct.
-#[inline]
+#[inline(always)]
 pub const fn base_prefix(format: u128) -> u8 {
     ((format & BASE_PREFIX) >> BASE_PREFIX_SHIFT) as u8
 }
 
 /// Extract the base suffix character from the format packed struct.
-#[inline]
+#[inline(always)]
 pub const fn base_suffix(format: u128) -> u8 {
     ((format & BASE_SUFFIX) >> BASE_SUFFIX_SHIFT) as u8
 }
 
 /// Extract the mantissa radix from the format packed struct.
-#[inline]
+#[inline(always)]
 pub const fn mantissa_radix(format: u128) -> u32 {
     ((format & MANTISSA_RADIX) >> MANTISSA_RADIX_SHIFT) as u32
 }
 
 /// Extract the exponent base from the format packed struct.
 /// If not provided, defaults to `mantissa_radix`.
-#[inline]
+#[inline(always)]
 pub const fn exponent_base(format: u128) -> u32 {
     let radix = ((format & EXPONENT_BASE) >> EXPONENT_BASE_SHIFT) as u32;
     if radix == 0 {
@@ -637,7 +637,7 @@ pub const fn exponent_base(format: u128) -> u32 {
 
 /// Extract the exponent radix from the format packed struct.
 /// If not provided, defaults to `mantissa_radix`.
-#[inline]
+#[inline(always)]
 pub const fn exponent_radix(format: u128) -> u32 {
     let radix = ((format & EXPONENT_RADIX) >> EXPONENT_RADIX_SHIFT) as u32;
     if radix == 0 {
@@ -648,7 +648,7 @@ pub const fn exponent_radix(format: u128) -> u32 {
 }
 
 /// Extract a generic radix from the format and bitflags.
-#[inline]
+#[inline(always)]
 pub const fn radix_from_flags(format: u128, mask: u128, shift: i32) -> u32 {
     let radix = ((format & mask) >> shift) as u32;
     if radix == 0 {
@@ -661,15 +661,18 @@ pub const fn radix_from_flags(format: u128, mask: u128, shift: i32) -> u32 {
 // VALIDATORS
 // ----------
 
+// NOTE: All of these are only used when building formats so it doesn't matter if
+// they have performance issues, since these will be built at compile time.
+
 /// Determine if the provided exponent flags are valid.
-#[inline]
+#[inline(always)]
 pub const fn is_valid_exponent_flags(format: u128) -> bool {
     // Both cannot be set.
     format & NO_EXPONENT_NOTATION == 0 || format & REQUIRED_EXPONENT_NOTATION == 0
 }
 
 /// Determine if an optional control character is valid.
-#[inline]
+#[inline(always)]
 const fn is_valid_optional_control_radix(radix: u32, value: u8) -> bool {
     // Validate the character isn't a digit or sign character, and is valid ASCII.
     use crate::ascii::is_valid_ascii;
@@ -681,7 +684,7 @@ const fn is_valid_optional_control_radix(radix: u32, value: u8) -> bool {
 }
 
 /// Determine if an optional control character is valid.
-#[inline]
+#[inline(always)]
 const fn is_valid_optional_control(format: u128, value: u8) -> bool {
     // Need to get the larger of the two radix values, since these
     // will be the characters that define the valid digits.
@@ -697,14 +700,14 @@ const fn is_valid_optional_control(format: u128, value: u8) -> bool {
 }
 
 /// Determine if an control character is valid.
-#[inline]
+#[inline(always)]
 const fn is_valid_control(format: u128, value: u8) -> bool {
     value != 0 && is_valid_optional_control(format, value)
 }
 
 /// Determine if the digit separator is valid.
 /// Digit separators must not be valid digits or sign characters.
-#[inline]
+#[inline(always)]
 pub const fn is_valid_digit_separator(format: u128) -> bool {
     let value = digit_separator(format);
     if cfg!(feature = "format") {
@@ -715,7 +718,7 @@ pub const fn is_valid_digit_separator(format: u128) -> bool {
 }
 
 /// Determine if the base prefix character is valid.
-#[inline]
+#[inline(always)]
 pub const fn is_valid_base_prefix(format: u128) -> bool {
     let value = base_prefix(format);
     if cfg!(feature = "format") {
@@ -726,7 +729,7 @@ pub const fn is_valid_base_prefix(format: u128) -> bool {
 }
 
 /// Determine if the base suffix character is valid.
-#[inline]
+#[inline(always)]
 pub const fn is_valid_base_suffix(format: u128) -> bool {
     let value = base_suffix(format);
     if cfg!(feature = "format") {
@@ -737,8 +740,8 @@ pub const fn is_valid_base_suffix(format: u128) -> bool {
 }
 
 /// Determine if all of the "punctuation" characters are valid.
-#[inline]
-#[allow(clippy::if_same_then_else)]
+#[inline(always)]
+#[allow(clippy::if_same_then_else)] // reason="all are different logic conditions"
 pub const fn is_valid_punctuation(format: u128) -> bool {
     // All the checks against optional characters with mandatory are fine:
     // if they're not 0, then they can't overlap, and mandatory can't be 0.
@@ -762,8 +765,9 @@ pub const fn is_valid_punctuation(format: u128) -> bool {
 }
 
 /// Determine if all of the "punctuation" characters for the options API are valid.
-#[inline]
-#[allow(clippy::if_same_then_else, clippy::needless_bool)]
+#[inline(always)]
+#[allow(clippy::if_same_then_else)] // reason="all are different logic conditions"
+#[allow(clippy::needless_bool)] // reason="not needless depending on the format condition"
 pub const fn is_valid_options_punctuation(format: u128, exponent: u8, decimal_point: u8) -> bool {
     // All the checks against optional characters with mandatory are fine:
     // if they're not 0, then they can't overlap, and mandatory can't be 0.
