@@ -4,11 +4,14 @@
 //! types, and trait bounds, and conversions for working with
 //! numbers in generic code.
 
+#![cfg_attr(any(), rustfmt::skip)]
+
+use core::{fmt, mem, ops};
+
 #[cfg(feature = "f16")]
 use crate::bf16::bf16;
 #[cfg(feature = "f16")]
 use crate::f16::f16;
-use core::{fmt, mem, ops};
 
 // AS PRIMITIVE
 // ------------
@@ -30,6 +33,7 @@ pub trait AsPrimitive: Copy + PartialEq + PartialOrd + Send + Sync + Sized {
     fn as_f32(self) -> f32;
     fn as_f64(self) -> f64;
     fn from_u32(value: u32) -> Self;
+    fn from_u64(value: u64) -> Self;
 
     #[cfg(feature = "f16")]
     fn as_f16(self) -> f16;
@@ -43,77 +47,82 @@ macro_rules! as_primitive {
         impl AsPrimitive for $t {
             #[inline(always)]
             fn as_u8(self) -> u8 {
-                self as _
+                self as u8
             }
 
             #[inline(always)]
             fn as_u16(self) -> u16 {
-                self as _
+                self as u16
             }
 
             #[inline(always)]
             fn as_u32(self) -> u32 {
-                self as _
+                self as u32
             }
 
             #[inline(always)]
             fn as_u64(self) -> u64 {
-                self as _
+                self as u64
             }
 
             #[inline(always)]
             fn as_u128(self) -> u128 {
-                self as _
+                self as u128
             }
 
             #[inline(always)]
             fn as_usize(self) -> usize {
-                self as _
+                self as usize
             }
 
             #[inline(always)]
             fn as_i8(self) -> i8 {
-                self as _
+                self as i8
             }
 
             #[inline(always)]
             fn as_i16(self) -> i16 {
-                self as _
+                self as i16
             }
 
             #[inline(always)]
             fn as_i32(self) -> i32 {
-                self as _
+                self as i32
             }
 
             #[inline(always)]
             fn as_i64(self) -> i64 {
-                self as _
+                self as i64
             }
 
             #[inline(always)]
             fn as_i128(self) -> i128 {
-                self as _
+                self as i128
             }
 
             #[inline(always)]
             fn as_isize(self) -> isize {
-                self as _
+                self as isize
             }
 
             #[inline(always)]
             fn as_f32(self) -> f32 {
-                self as _
+                self as f32
             }
 
             #[inline(always)]
             fn as_f64(self) -> f64 {
-                self as _
+                self as f64
             }
 
             #[inline(always)]
             fn from_u32(value: u32) -> Self {
-                value as _
+                value as Self
+            }
+
+            #[inline(always)]
+            fn from_u64(value: u64) -> Self {
+                value as Self
             }
 
             #[cfg(feature = "f16")]
@@ -139,79 +148,86 @@ macro_rules! half_as_primitive {
         impl AsPrimitive for $t {
             #[inline(always)]
             fn as_u8(self) -> u8 {
-                self.as_f32() as _
+                self.as_f32() as u8
             }
 
             #[inline(always)]
             fn as_u16(self) -> u16 {
-                self.as_f32() as _
+                self.as_f32() as u16
             }
 
             #[inline(always)]
             fn as_u32(self) -> u32 {
-                self.as_f32() as _
+                self.as_f32() as u32
             }
 
             #[inline(always)]
             fn as_u64(self) -> u64 {
-                self.as_f32() as _
+                self.as_f32() as u64
             }
 
             #[inline(always)]
             fn as_u128(self) -> u128 {
-                self.as_f32() as _
+                self.as_f32() as u128
             }
 
             #[inline(always)]
             fn as_usize(self) -> usize {
-                self.as_f32() as _
+                self.as_f32() as usize
             }
 
             #[inline(always)]
             fn as_i8(self) -> i8 {
-                self.as_f32() as _
+                self.as_f32() as i8
             }
 
             #[inline(always)]
             fn as_i16(self) -> i16 {
-                self.as_f32() as _
+                self.as_f32() as i16
             }
 
             #[inline(always)]
             fn as_i32(self) -> i32 {
-                self.as_f32() as _
+                self.as_f32() as i32
             }
 
             #[inline(always)]
             fn as_i64(self) -> i64 {
-                self.as_f32() as _
+                self.as_f32() as i64
             }
 
             #[inline(always)]
             fn as_i128(self) -> i128 {
-                self.as_f32() as _
+                self.as_f32() as i128
             }
 
             #[inline(always)]
             fn as_isize(self) -> isize {
-                self.as_f32() as _
+                self.as_f32() as isize
             }
 
             #[inline(always)]
             fn as_f32(self) -> f32 {
-                self.as_f32() as _
+                self.as_f32() as f32
             }
 
             #[inline(always)]
             fn as_f64(self) -> f64 {
-                self.as_f32() as _
+                self.as_f32() as f64
             }
 
             #[inline(always)]
+            #[allow(clippy::as_underscore)] // reason="intentionally used in a generic sense"
             fn from_u32(value: u32) -> Self {
                 Self::from_f32(value as _)
             }
 
+            #[inline(always)]
+            fn from_u64(value: u64) -> Self {
+                _ = value;
+                unimplemented!()
+            }
+
             #[inline(always)]
             fn as_f16(self) -> f16 {
                 f16::from_f32(self.as_f32())
@@ -239,7 +255,7 @@ pub trait AsCast: AsPrimitive {
 }
 
 /// Allows the high-level conversion of generic types as if `as` was used.
-#[inline]
+#[inline(always)]
 pub fn as_cast<U: AsCast, T: AsCast>(t: T) -> U {
     U::as_cast(t)
 }
@@ -247,7 +263,8 @@ pub fn as_cast<U: AsCast, T: AsCast>(t: T) -> U {
 macro_rules! as_cast {
     ($($t:ty, $meth:ident ; )*) => ($(
         impl AsCast for $t {
-            #[inline]
+            #[inline(always)]
+            #[allow(clippy::as_underscore)] // reason="intentional due to generic API"
             fn as_cast<N: AsPrimitive>(n: N) -> $t {
                 n.$meth() as _
             }
@@ -383,10 +400,13 @@ pub trait Integer:
     fn leading_zeros(self) -> u32;
     fn trailing_zeros(self) -> u32;
     fn pow(self, exp: u32) -> Self;
+    fn checked_pow(self, exp: u32) -> Option<Self>;
+    fn overflowing_pow(self, exp: u32) -> (Self, bool);
     fn checked_add(self, i: Self) -> Option<Self>;
     fn checked_sub(self, i: Self) -> Option<Self>;
     fn checked_mul(self, i: Self) -> Option<Self>;
     fn overflowing_add(self, i: Self) -> (Self, bool);
+    fn overflowing_sub(self, i: Self) -> (Self, bool);
     fn overflowing_mul(self, i: Self) -> (Self, bool);
     fn wrapping_add(self, i: Self) -> Self;
     fn wrapping_sub(self, i: Self) -> Self;
@@ -398,7 +418,7 @@ pub trait Integer:
 
     /// Get the fast ceiling of the quotient from integer division.
     /// Not safe, since the remainder can easily overflow.
-    #[inline]
+    #[inline(always)]
     fn ceil_divmod(self, y: Self) -> (Self, i32) {
         let q = self / y;
         let r = self % y;
@@ -410,14 +430,14 @@ pub trait Integer:
 
     /// Get the fast ceiling of the quotient from integer division.
     /// Not safe, since the remainder can easily overflow.
-    #[inline]
+    #[inline(always)]
     fn ceil_div(self, y: Self) -> Self {
         self.ceil_divmod(y).0
     }
 
     /// Get the fast ceiling modulus from integer division.
     /// Not safe, since the remainder can easily overflow.
-    #[inline]
+    #[inline(always)]
     fn ceil_mod(self, y: Self) -> i32 {
         self.ceil_divmod(y).1
     }
@@ -425,114 +445,144 @@ pub trait Integer:
     // PROPERTIES
 
     /// Get the number of bits in a value.
-    #[inline]
+    #[inline(always)]
     fn bit_length(self) -> u32 {
         Self::BITS as u32 - self.leading_zeros()
     }
 
     /// Returns true if the least-significant bit is odd.
-    #[inline]
+    #[inline(always)]
     fn is_odd(self) -> bool {
         self & Self::ONE == Self::ONE
     }
 
     /// Returns true if the least-significant bit is even.
-    #[inline]
+    #[inline(always)]
     fn is_even(self) -> bool {
         !self.is_odd()
     }
+
+    /// Get the maximum number of digits before the slice will overflow.
+    ///
+    /// This is effectively the floor(log(2**BITS-1, radix)), but we can
+    /// try to go a bit lower without worrying too much.
+    #[inline(always)]
+    fn overflow_digits(radix: u32) -> usize {
+        // this is heavily optimized for base10 and it's a way under estimate
+        // that said, it's fast and works.
+        if radix <= 16 {
+            mem::size_of::<Self>() * 2 - Self::IS_SIGNED as usize
+        } else {
+            // way under approximation but always works and is fast
+            mem::size_of::<Self>()
+        }
+    }
 }
 
 macro_rules! integer_impl {
-    ($($t:tt)*) => ($(
-        impl Integer for $t {
-            const ZERO: $t = 0;
-            const ONE: $t = 1;
-            const TWO: $t = 2;
-            const MAX: $t = $t::max_value();
-            const MIN: $t = $t::min_value();
-            // DEPRECATE: when we drop support for <= 1.53.0, change to `<$t>::BITS`
-            const BITS: usize = mem::size_of::<$t>() * 8;
+($($t:tt)*) => ($(
+    impl Integer for $t {
+        const ZERO: $t = 0;
+        const ONE: $t = 1;
+        const TWO: $t = 2;
+        const MAX: $t = $t::MAX;
+        const MIN: $t = $t::MIN;
+        const BITS: usize = $t::BITS as usize;
 
-            #[inline]
-            fn leading_zeros(self) -> u32 {
-                $t::leading_zeros(self)
-            }
-
-            #[inline]
-            fn trailing_zeros(self) -> u32 {
-                $t::trailing_zeros(self)
-            }
-
-            #[inline]
-            fn checked_add(self, i: Self) -> Option<Self> {
-                $t::checked_add(self, i)
-            }
-
-            #[inline]
-            fn checked_sub(self, i: Self) -> Option<Self> {
-                $t::checked_sub(self, i)
-            }
-
-            #[inline]
-            fn checked_mul(self, i: Self) -> Option<Self> {
-                $t::checked_mul(self, i)
-            }
-
-            #[inline]
-            fn overflowing_add(self, i: Self) -> (Self, bool) {
-                $t::overflowing_add(self, i)
-            }
-
-            #[inline]
-            fn overflowing_mul(self, i: Self) -> (Self, bool) {
-                $t::overflowing_mul(self, i)
-            }
-
-            #[inline]
-            fn wrapping_add(self, i: Self) -> Self {
-                $t::wrapping_add(self, i)
-            }
-
-            #[inline]
-            fn wrapping_sub(self, i: Self) -> Self {
-                $t::wrapping_sub(self, i)
-            }
-
-            #[inline]
-            fn wrapping_mul(self, i: Self) -> Self {
-                $t::wrapping_mul(self, i)
-            }
-
-            #[inline]
-            fn wrapping_neg(self) -> Self {
-                $t::wrapping_neg(self)
-            }
-
-            #[inline]
-            fn pow(self, exp: u32) -> Self {
-                Self::pow(self, exp)
-            }
-
-            #[inline]
-            fn saturating_add(self, i: Self) -> Self {
-                $t::saturating_add(self, i)
-            }
-
-            #[inline]
-            fn saturating_sub(self, i: Self) -> Self {
-                $t::saturating_sub(self, i)
-            }
-
-            #[inline]
-            fn saturating_mul(self, i: Self) -> Self {
-                $t::saturating_mul(self, i)
-            }
+        #[inline(always)]
+        fn leading_zeros(self) -> u32 {
+            $t::leading_zeros(self)
         }
-    )*)
+
+        #[inline(always)]
+        fn trailing_zeros(self) -> u32 {
+            $t::trailing_zeros(self)
+        }
+
+        #[inline(always)]
+        fn checked_add(self, i: Self) -> Option<Self> {
+            $t::checked_add(self, i)
+        }
+
+        #[inline(always)]
+        fn checked_sub(self, i: Self) -> Option<Self> {
+            $t::checked_sub(self, i)
+        }
+
+        #[inline(always)]
+        fn checked_mul(self, i: Self) -> Option<Self> {
+            $t::checked_mul(self, i)
+        }
+
+        #[inline(always)]
+        fn overflowing_add(self, i: Self) -> (Self, bool) {
+            $t::overflowing_add(self, i)
+        }
+
+        #[inline(always)]
+        fn overflowing_sub(self, i: Self) -> (Self, bool) {
+            $t::overflowing_sub(self, i)
+        }
+
+        #[inline(always)]
+        fn overflowing_mul(self, i: Self) -> (Self, bool) {
+            $t::overflowing_mul(self, i)
+        }
+
+        #[inline(always)]
+        fn wrapping_add(self, i: Self) -> Self {
+            $t::wrapping_add(self, i)
+        }
+
+        #[inline(always)]
+        fn wrapping_sub(self, i: Self) -> Self {
+            $t::wrapping_sub(self, i)
+        }
+
+        #[inline(always)]
+        fn wrapping_mul(self, i: Self) -> Self {
+            $t::wrapping_mul(self, i)
+        }
+
+        #[inline(always)]
+        fn wrapping_neg(self) -> Self {
+            $t::wrapping_neg(self)
+        }
+
+        #[inline(always)]
+        fn pow(self, exp: u32) -> Self {
+            Self::pow(self, exp)
+        }
+
+        #[inline(always)]
+        fn checked_pow(self, exp: u32) -> Option<Self> {
+            Self::checked_pow(self, exp)
+        }
+
+        #[inline(always)]
+        fn overflowing_pow(self, exp: u32) -> (Self, bool) {
+            Self::overflowing_pow(self, exp)
+        }
+
+        #[inline(always)]
+        fn saturating_add(self, i: Self) -> Self {
+            $t::saturating_add(self, i)
+        }
+
+        #[inline(always)]
+        fn saturating_sub(self, i: Self) -> Self {
+            $t::saturating_sub(self, i)
+        }
+
+        #[inline(always)]
+        fn saturating_mul(self, i: Self) -> Self {
+            $t::saturating_mul(self, i)
+        }
+    }
+)*)
 }
 
-integer_impl! { u8 u16 u32 u64 u128 usize i8 i16 i32 i64 i128 isize }
+integer_impl! { u8 u16 u32 u64 u128 i8 i16 i32 i64 i128 usize isize }
 
 // SIGNED INTEGER
 // --------------
@@ -541,9 +591,9 @@ integer_impl! { u8 u16 u32 u64 u128 usize i8 i16 i32 i64 i128 isize }
 pub trait SignedInteger: Integer + ops::Neg<Output = Self> {}
 
 macro_rules! signed_integer_impl {
-    ($($t:tt)*) => ($(
-        impl SignedInteger for $t {}
-    )*)
+($($t:tt)*) => ($(
+    impl SignedInteger for $t {}
+)*)
 }
 
 signed_integer_impl! { i8 i16 i32 i64 i128 isize }
@@ -555,9 +605,9 @@ signed_integer_impl! { i8 i16 i32 i64 i128 isize }
 pub trait UnsignedInteger: Integer {}
 
 macro_rules! unsigned_integer_impl {
-    ($($t:ty)*) => ($(
-        impl UnsignedInteger for $t {}
-    )*)
+($($t:ty)*) => ($(
+    impl UnsignedInteger for $t {}
+)*)
 }
 
 unsigned_integer_impl! { u8 u16 u32 u64 u128 usize }
@@ -586,7 +636,8 @@ pub trait Float: Number + ops::Neg<Output = Self> {
     const SIGN_MASK: Self::Unsigned;
     /// Bitmask for the exponent, including the hidden bit.
     const EXPONENT_MASK: Self::Unsigned;
-    /// Bitmask for the hidden bit in exponent, which is an implicit 1 in the fraction.
+    /// Bitmask for the hidden bit in exponent, which is an implicit 1 in the
+    /// fraction.
     const HIDDEN_BIT_MASK: Self::Unsigned;
     /// Bitmask for the mantissa (fraction), excluding the hidden bit.
     const MANTISSA_MASK: Self::Unsigned;
@@ -628,43 +679,52 @@ pub trait Float: Number + ops::Neg<Output = Self> {
     fn is_sign_negative(self) -> bool;
 
     /// Returns true if the float is a denormal.
-    #[inline]
+    #[inline(always)]
     fn is_denormal(self) -> bool {
         self.to_bits() & Self::EXPONENT_MASK == Self::Unsigned::ZERO
     }
 
     /// Returns true if the float is a NaN or Infinite.
-    #[inline]
+    #[inline(always)]
     fn is_special(self) -> bool {
         self.to_bits() & Self::EXPONENT_MASK == Self::EXPONENT_MASK
     }
 
     /// Returns true if the float is NaN.
-    #[inline]
+    #[inline(always)]
     fn is_nan(self) -> bool {
         self.is_special() && (self.to_bits() & Self::MANTISSA_MASK) != Self::Unsigned::ZERO
     }
 
     /// Returns true if the float is infinite.
-    #[inline]
+    #[inline(always)]
     fn is_inf(self) -> bool {
         self.is_special() && (self.to_bits() & Self::MANTISSA_MASK) == Self::Unsigned::ZERO
     }
 
     /// Returns true if the float's least-significant mantissa bit is odd.
-    #[inline]
+    #[inline(always)]
     fn is_odd(self) -> bool {
         self.to_bits().is_odd()
     }
 
     /// Returns true if the float's least-significant mantissa bit is even.
-    #[inline]
+    #[inline(always)]
     fn is_even(self) -> bool {
         !self.is_odd()
     }
 
+    /// Returns true if the float needs a negative sign when serializing it.
+    ///
+    /// This is true if it's `-0.0` or it's below 0 and not NaN. But inf values
+    /// need the sign.
+    #[inline(always)]
+    fn needs_negative_sign(self) -> bool {
+        self.is_sign_negative() && !self.is_nan()
+    }
+
     /// Get exponent component from the float.
-    #[inline]
+    #[inline(always)]
     fn exponent(self) -> i32 {
         if self.is_denormal() {
             return Self::DENORMAL_EXPONENT;
@@ -676,7 +736,7 @@ pub trait Float: Number + ops::Neg<Output = Self> {
     }
 
     /// Get mantissa (significand) component from float.
-    #[inline]
+    #[inline(always)]
     fn mantissa(self) -> Self::Unsigned {
         let bits = self.to_bits();
         let s = bits & Self::MANTISSA_MASK;
@@ -688,7 +748,7 @@ pub trait Float: Number + ops::Neg<Output = Self> {
     }
 
     /// Get next greater float.
-    #[inline]
+    #[inline(always)]
     fn next(self) -> Self {
         let bits = self.to_bits();
         if self.is_sign_negative() && self == Self::ZERO {
@@ -705,14 +765,14 @@ pub trait Float: Number + ops::Neg<Output = Self> {
 
     /// Get next greater float for a positive float.
     /// Value must be >= 0.0 and < INFINITY.
-    #[inline]
+    #[inline(always)]
     fn next_positive(self) -> Self {
         debug_assert!(self.is_sign_positive() && !self.is_inf());
         Self::from_bits(self.to_bits() + Self::Unsigned::ONE)
     }
 
     /// Get previous greater float, such that `self.prev().next() == self`.
-    #[inline]
+    #[inline(always)]
     fn prev(self) -> Self {
         let bits = self.to_bits();
         if self.is_sign_positive() && self == Self::ZERO {
@@ -729,14 +789,14 @@ pub trait Float: Number + ops::Neg<Output = Self> {
 
     /// Get previous greater float for a positive float.
     /// Value must be > 0.0.
-    #[inline]
+    #[inline(always)]
     fn prev_positive(self) -> Self {
         debug_assert!(self.is_sign_positive() && self != Self::ZERO);
         Self::from_bits(self.to_bits() - Self::Unsigned::ONE)
     }
 
     /// Round a positive number to even.
-    #[inline]
+    #[inline(always)]
     fn round_positive_even(self) -> Self {
         if self.mantissa().is_odd() {
             self.next_positive()
@@ -746,7 +806,7 @@ pub trait Float: Number + ops::Neg<Output = Self> {
     }
 
     /// Get the max of two finite numbers.
-    #[inline]
+    #[inline(always)]
     fn max_finite(self, f: Self) -> Self {
         debug_assert!(!self.is_special() && !f.is_special(), "max_finite self={} f={}", self, f);
         if self < f {
@@ -757,7 +817,7 @@ pub trait Float: Number + ops::Neg<Output = Self> {
     }
 
     /// Get the min of two finite numbers.
-    #[inline]
+    #[inline(always)]
     fn min_finite(self, f: Self) -> Self {
         debug_assert!(!self.is_special() && !f.is_special(), "min_finite self={} f={}", self, f);
         if self < f {
@@ -874,32 +934,32 @@ impl Float for f16 {
     const DENORMAL_EXPONENT: i32 = 1 - Self::EXPONENT_BIAS;
     const MAX_EXPONENT: i32 = 0x1F - Self::EXPONENT_BIAS;
 
-    #[inline]
+    #[inline(always)]
     fn to_bits(self) -> u16 {
         f16::to_bits(self)
     }
 
-    #[inline]
+    #[inline(always)]
     fn from_bits(u: u16) -> f16 {
         f16::from_bits(u)
     }
 
-    #[inline]
+    #[inline(always)]
     fn ln(self) -> f16 {
         f16::from_f32(self.as_f32().ln())
     }
 
-    #[inline]
+    #[inline(always)]
     fn floor(self) -> f16 {
         f16::from_f32(self.as_f32().floor())
     }
 
-    #[inline]
+    #[inline(always)]
     fn is_sign_positive(self) -> bool {
         self.to_bits() & Self::SIGN_MASK == 0
     }
 
-    #[inline]
+    #[inline(always)]
     fn is_sign_negative(self) -> bool {
         !self.is_sign_positive()
     }
@@ -932,32 +992,32 @@ impl Float for bf16 {
     const DENORMAL_EXPONENT: i32 = 1 - Self::EXPONENT_BIAS;
     const MAX_EXPONENT: i32 = 0xFF - Self::EXPONENT_BIAS;
 
-    #[inline]
+    #[inline(always)]
     fn to_bits(self) -> u16 {
         bf16::to_bits(self)
     }
 
-    #[inline]
+    #[inline(always)]
     fn from_bits(u: u16) -> bf16 {
         bf16::from_bits(u)
     }
 
-    #[inline]
+    #[inline(always)]
     fn ln(self) -> bf16 {
         bf16::from_f32(self.as_f32().ln())
     }
 
-    #[inline]
+    #[inline(always)]
     fn floor(self) -> bf16 {
         bf16::from_f32(self.as_f32().floor())
     }
 
-    #[inline]
+    #[inline(always)]
     fn is_sign_positive(self) -> bool {
         self.to_bits() & Self::SIGN_MASK == 0
     }
 
-    #[inline]
+    #[inline(always)]
     fn is_sign_negative(self) -> bool {
         !self.is_sign_positive()
     }
@@ -980,17 +1040,17 @@ impl Float for f32 {
     const DENORMAL_EXPONENT: i32 = 1 - Self::EXPONENT_BIAS;
     const MAX_EXPONENT: i32 = 0xFF - Self::EXPONENT_BIAS;
 
-    #[inline]
+    #[inline(always)]
     fn to_bits(self) -> u32 {
         f32::to_bits(self)
     }
 
-    #[inline]
+    #[inline(always)]
     fn from_bits(u: u32) -> f32 {
         f32::from_bits(u)
     }
 
-    #[inline]
+    #[inline(always)]
     fn ln(self) -> f32 {
         #[cfg(feature = "std")]
         return f32::ln(self);
@@ -999,7 +1059,7 @@ impl Float for f32 {
         return logf(self);
     }
 
-    #[inline]
+    #[inline(always)]
     fn floor(self) -> f32 {
         #[cfg(feature = "std")]
         return f32::floor(self);
@@ -1008,12 +1068,12 @@ impl Float for f32 {
         return floorf(self);
     }
 
-    #[inline]
+    #[inline(always)]
     fn is_sign_positive(self) -> bool {
         f32::is_sign_positive(self)
     }
 
-    #[inline]
+    #[inline(always)]
     fn is_sign_negative(self) -> bool {
         f32::is_sign_negative(self)
     }
@@ -1036,17 +1096,17 @@ impl Float for f64 {
     const DENORMAL_EXPONENT: i32 = 1 - Self::EXPONENT_BIAS;
     const MAX_EXPONENT: i32 = 0x7FF - Self::EXPONENT_BIAS;
 
-    #[inline]
+    #[inline(always)]
     fn to_bits(self) -> u64 {
         f64::to_bits(self)
     }
 
-    #[inline]
+    #[inline(always)]
     fn from_bits(u: u64) -> f64 {
         f64::from_bits(u)
     }
 
-    #[inline]
+    #[inline(always)]
     fn ln(self) -> f64 {
         #[cfg(feature = "std")]
         return f64::ln(self);
@@ -1055,7 +1115,7 @@ impl Float for f64 {
         return logd(self);
     }
 
-    #[inline]
+    #[inline(always)]
     fn floor(self) -> f64 {
         #[cfg(feature = "std")]
         return f64::floor(self);
@@ -1064,12 +1124,12 @@ impl Float for f64 {
         return floord(self);
     }
 
-    #[inline]
+    #[inline(always)]
     fn is_sign_positive(self) -> bool {
         f64::is_sign_positive(self)
     }
 
-    #[inline]
+    #[inline(always)]
     fn is_sign_negative(self) -> bool {
         f64::is_sign_negative(self)
     }
@@ -1105,12 +1165,12 @@ impl Float for f64 {
 /// Safe as long as `e` is properly initialized.
 #[cfg(all(not(feature = "std"), feature = "floats"))]
 macro_rules! volatile {
-    ($e:expr) => {
-        // SAFETY: safe as long as `$e` has been properly initialized.
-        unsafe {
-            core::ptr::read_volatile(&$e);
-        }
-    };
+($e:expr) => {
+    // SAFETY: safe as long as `$e` has been properly initialized.
+    unsafe {
+        core::ptr::read_volatile(&$e);
+    }
+};
 }
 
 /// Floor (f64)
@@ -1242,7 +1302,7 @@ fn floorf(x: f32) -> f32 {
  * to produce the hexadecimal values shown.
  */
 
-#[allow(clippy::eq_op, clippy::excessive_precision)]
+#[allow(clippy::eq_op, clippy::excessive_precision)] // reason="values need to be exact under all conditions"
 #[cfg(all(not(feature = "std"), feature = "floats"))]
 fn logd(mut x: f64) -> f64 {
     const LN2_HI: f64 = 6.93147180369123816490e-01; /* 3fe62e42 fee00000 */
@@ -1262,7 +1322,7 @@ fn logd(mut x: f64) -> f64 {
     let mut k: i32 = 0;
 
     if (hx < 0x00100000) || ((hx >> 31) != 0) {
-        /* x < 2**-126  */
+        /* x < 2**-126 */
         if ui << 1 == 0 {
             return -1. / (x * x); /* log(+-0)=-inf */
         }
@@ -1314,16 +1374,16 @@ fn logd(mut x: f64) -> f64 {
  * ====================================================
  */
 
-#[allow(clippy::eq_op, clippy::excessive_precision)]
+#[allow(clippy::eq_op, clippy::excessive_precision)] // reason="values need to be exact under all conditions"
 #[cfg(all(not(feature = "std"), feature = "floats"))]
 fn logf(mut x: f32) -> f32 {
     const LN2_HI: f32 = 6.9313812256e-01; /* 0x3f317180 */
     const LN2_LO: f32 = 9.0580006145e-06; /* 0x3717f7d1 */
     /* |(log(1+s)-log(1-s))/s - Lg(s)| < 2**-34.24 (~[-4.95e-11, 4.97e-11]). */
-    const LG1: f32 = 0.66666662693; /*  0xaaaaaa.0p-24*/
-    const LG2: f32 = 0.40000972152; /*  0xccce13.0p-25 */
-    const LG3: f32 = 0.28498786688; /*  0x91e9ee.0p-25 */
-    const LG4: f32 = 0.24279078841; /*  0xf89e26.0p-26 */
+    const LG1: f32 = 0.66666662693; /* 0xaaaaaa.0p-24 */
+    const LG2: f32 = 0.40000972152; /* 0xccce13.0p-25 */
+    const LG3: f32 = 0.28498786688; /* 0x91e9ee.0p-25 */
+    const LG4: f32 = 0.24279078841; /* 0xf89e26.0p-26 */
 
     let x1p25 = f32::from_bits(0x4c000000); // 0x1p25f === 2 ^ 25
 
@@ -1331,7 +1391,7 @@ fn logf(mut x: f32) -> f32 {
     let mut k = 0i32;
 
     if (ix < 0x00800000) || ((ix >> 31) != 0) {
-        /* x < 2**-126  */
+        /* x < 2**-126 */
         if ix << 1 == 0 {
             return -1. / (x * x); /* log(+-0)=-inf */
         }
