@@ -1,4 +1,5 @@
-//! The maximum digits that can be held in a u64 for a given radix without overflow.
+//! The maximum digits that can be held in a u64 for a given radix without
+//! overflow.
 //!
 //! This is useful for 128-bit division and operations, since it can
 //! reduces the number of inefficient, non-native operations.
@@ -16,13 +17,19 @@
 //  Fallback radixes use 1 for the value to avoid infinite loops,
 //  but allowing them in `const fn`.
 
+/// Get the maximum number of digits that can be processed without overflowing.
+///
 /// Calculate the maximum number of digits that can always be processed
 /// without overflowing for a given type. For example, 19 digits can
 /// always be processed for a decimal string for `u64` without overflowing.
 #[inline(always)]
+#[allow(clippy::needless_return)] // reason="required depending on our radix configuration"
 pub const fn min_step(radix: u32, bits: usize, is_signed: bool) -> usize {
-    if cfg!(feature = "radix") {
-        match radix {
+    // NOTE: to avoid branching when w don't need it, we use the compile logic
+
+    #[cfg(feature = "radix")]
+    {
+        return match radix {
             2 => min_step_2(bits, is_signed),
             3 => min_step_3(bits, is_signed),
             4 => min_step_4(bits, is_signed),
@@ -59,9 +66,12 @@ pub const fn min_step(radix: u32, bits: usize, is_signed: bool) -> usize {
             35 => min_step_35(bits, is_signed),
             36 => min_step_36(bits, is_signed),
             _ => 1,
-        }
-    } else if cfg!(feature = "power-of-two") {
-        match radix {
+        };
+    }
+
+    #[cfg(all(feature = "power-of-two", not(feature = "radix")))]
+    {
+        return match radix {
             2 => min_step_2(bits, is_signed),
             4 => min_step_4(bits, is_signed),
             8 => min_step_8(bits, is_signed),
@@ -69,20 +79,28 @@ pub const fn min_step(radix: u32, bits: usize, is_signed: bool) -> usize {
             16 => min_step_16(bits, is_signed),
             32 => min_step_32(bits, is_signed),
             _ => 1,
-        }
-    } else {
-        min_step_10(bits, is_signed)
+        };
+    }
+
+    #[cfg(not(feature = "power-of-two"))]
+    {
+        _ = radix;
+        return min_step_10(bits, is_signed);
     }
 }
 
+/// Get the maximum number of digits that can be processed without overflowing.
+///
 /// Calculate the maximum number of digits that can be processed
 /// without always overflowing for a given type. For example, 20 digits can
 /// be processed for a decimal string for `u64` without overflowing, but
 /// it may overflow.
 #[inline(always)]
+#[allow(clippy::needless_return)] // reason="required depending on our radix configuration"
 pub const fn max_step(radix: u32, bits: usize, is_signed: bool) -> usize {
-    if cfg!(feature = "radix") {
-        match radix {
+    #[cfg(feature = "radix")]
+    {
+        return match radix {
             2 => max_step_2(bits, is_signed),
             3 => max_step_3(bits, is_signed),
             4 => max_step_4(bits, is_signed),
@@ -119,9 +137,12 @@ pub const fn max_step(radix: u32, bits: usize, is_signed: bool) -> usize {
             35 => max_step_35(bits, is_signed),
             36 => max_step_36(bits, is_signed),
             _ => 1,
-        }
-    } else if cfg!(feature = "power-of-two") {
-        match radix {
+        };
+    }
+
+    #[cfg(all(feature = "power-of-two", not(feature = "radix")))]
+    {
+        return match radix {
             2 => max_step_2(bits, is_signed),
             4 => max_step_4(bits, is_signed),
             8 => max_step_8(bits, is_signed),
@@ -129,14 +150,18 @@ pub const fn max_step(radix: u32, bits: usize, is_signed: bool) -> usize {
             16 => max_step_16(bits, is_signed),
             32 => max_step_32(bits, is_signed),
             _ => 1,
-        }
-    } else {
-        max_step_10(bits, is_signed)
+        };
+    }
+
+    #[cfg(not(feature = "power-of-two"))]
+    {
+        _ = radix;
+        return max_step_10(bits, is_signed);
     }
 }
 
-/// Calculate the number of digits that can be processed without overflowing a u64.
-/// Helper function since this is used for 128-bit division.
+/// Calculate the number of digits that can be processed without overflowing a
+/// u64. Helper function since this is used for 128-bit division.
 #[inline(always)]
 pub const fn u64_step(radix: u32) -> usize {
     min_step(radix, 64, false)
@@ -151,7 +176,8 @@ pub const fn u64_step(radix: u32) -> usize {
 // or wider type support in the future), use 1 so it doesn't infinitely
 // recurse. Under normal circumstances, this will never be called.
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn max_step_2(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 7,
@@ -168,7 +194,8 @@ const fn max_step_2(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn min_step_2(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 7,
@@ -185,7 +212,8 @@ const fn min_step_2(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_3(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 5,
@@ -202,7 +230,8 @@ const fn max_step_3(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_3(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 4,
@@ -219,7 +248,8 @@ const fn min_step_3(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn max_step_4(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 4,
@@ -236,7 +266,8 @@ const fn max_step_4(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn min_step_4(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 3,
@@ -253,7 +284,8 @@ const fn min_step_4(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_5(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 4,
@@ -270,7 +302,8 @@ const fn max_step_5(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_5(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 3,
@@ -287,7 +320,8 @@ const fn min_step_5(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_6(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 3,
@@ -304,7 +338,8 @@ const fn max_step_6(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_6(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -321,7 +356,8 @@ const fn min_step_6(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_7(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 3,
@@ -338,7 +374,8 @@ const fn max_step_7(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_7(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -355,7 +392,8 @@ const fn min_step_7(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn max_step_8(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 3,
@@ -372,7 +410,8 @@ const fn max_step_8(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn min_step_8(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -389,7 +428,8 @@ const fn min_step_8(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_9(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 3,
@@ -406,7 +446,8 @@ const fn max_step_9(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_9(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -423,7 +464,7 @@ const fn min_step_9(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
 const fn max_step_10(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 3,
@@ -440,7 +481,7 @@ const fn max_step_10(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
 const fn min_step_10(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -457,7 +498,8 @@ const fn min_step_10(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_11(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 3,
@@ -474,7 +516,8 @@ const fn max_step_11(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_11(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -491,7 +534,8 @@ const fn min_step_11(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_12(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -508,7 +552,8 @@ const fn max_step_12(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_12(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -525,7 +570,8 @@ const fn min_step_12(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_13(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -542,7 +588,8 @@ const fn max_step_13(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_13(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -559,7 +606,8 @@ const fn min_step_13(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_14(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -576,7 +624,8 @@ const fn max_step_14(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_14(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -593,7 +642,8 @@ const fn min_step_14(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_15(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -610,7 +660,8 @@ const fn max_step_15(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_15(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -627,7 +678,8 @@ const fn min_step_15(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn max_step_16(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -644,7 +696,8 @@ const fn max_step_16(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn min_step_16(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -661,7 +714,8 @@ const fn min_step_16(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_17(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -678,7 +732,8 @@ const fn max_step_17(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_17(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -695,7 +750,8 @@ const fn min_step_17(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_18(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -712,7 +768,8 @@ const fn max_step_18(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_18(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -729,7 +786,8 @@ const fn min_step_18(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_19(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -746,7 +804,8 @@ const fn max_step_19(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_19(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -763,7 +822,8 @@ const fn min_step_19(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_20(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -780,7 +840,8 @@ const fn max_step_20(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_20(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -797,7 +858,8 @@ const fn min_step_20(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_21(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -814,7 +876,8 @@ const fn max_step_21(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_21(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -831,7 +894,8 @@ const fn min_step_21(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_22(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -848,7 +912,8 @@ const fn max_step_22(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_22(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -865,7 +930,8 @@ const fn min_step_22(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_23(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -882,7 +948,8 @@ const fn max_step_23(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_23(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -899,7 +966,8 @@ const fn min_step_23(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_24(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -916,7 +984,8 @@ const fn max_step_24(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_24(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -933,7 +1002,8 @@ const fn min_step_24(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_25(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -950,7 +1020,8 @@ const fn max_step_25(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_25(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -967,7 +1038,8 @@ const fn min_step_25(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_26(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -984,7 +1056,8 @@ const fn max_step_26(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_26(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1001,7 +1074,8 @@ const fn min_step_26(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_27(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1018,7 +1092,8 @@ const fn max_step_27(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_27(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1035,7 +1110,8 @@ const fn min_step_27(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_28(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1052,7 +1128,8 @@ const fn max_step_28(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_28(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1069,7 +1146,8 @@ const fn min_step_28(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_29(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1086,7 +1164,8 @@ const fn max_step_29(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_29(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1103,7 +1182,8 @@ const fn min_step_29(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_30(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1120,7 +1200,8 @@ const fn max_step_30(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_30(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1137,7 +1218,8 @@ const fn min_step_30(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_31(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1154,7 +1236,8 @@ const fn max_step_31(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_31(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1171,7 +1254,8 @@ const fn min_step_31(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn max_step_32(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1188,7 +1272,8 @@ const fn max_step_32(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "power-of-two"), allow(dead_code))]
 const fn min_step_32(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1205,7 +1290,8 @@ const fn min_step_32(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_33(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1222,7 +1308,8 @@ const fn max_step_33(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_33(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1239,7 +1326,8 @@ const fn min_step_33(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_34(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1256,7 +1344,8 @@ const fn max_step_34(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_34(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1273,7 +1362,8 @@ const fn min_step_34(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_35(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1290,7 +1380,8 @@ const fn max_step_35(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_35(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
@@ -1307,7 +1398,8 @@ const fn min_step_35(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn max_step_36(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 2,
@@ -1324,7 +1416,8 @@ const fn max_step_36(bits: usize, is_signed: bool) -> usize {
     }
 }
 
-#[inline]
+#[inline(always)]
+#[cfg_attr(not(feature = "radix"), allow(dead_code))]
 const fn min_step_36(bits: usize, is_signed: bool) -> usize {
     match bits {
         8 if is_signed => 1,
